@@ -16,12 +16,6 @@ use Text::Patch;
 use Text::Diff;
 #use Win32;
 
-sub new {
-  my $class = shift;
-  my $self = $class->SUPER::new(@_);
-  return $self;
-}
-
 sub check {
   my $self = shift;
   my ($rv, $out);
